import re
from dosage.modules.helpers.BasicComicModule import BasicComicModule

class Qwantz(BasicComicModule):
    latestUrl = 'http://www.qwantz.com/'
    imageUrl = 'http://www.qwantz.com/%s.html'
    imageSearch = re.compile(r'"(/comics/.+?)"')
    prevSearch = re.compile(r'"(index.pl\?comic=[^"\r\n]+)">previous')
    help = 'Index format: yyyymmdd'
